/*
 * Copyright (C) 2008-2013 Andre Noll <maan@systemlinux.org>
 *
 * Licensed under the GPL v2. For licencing details see COPYING.
 */

/** \file ggo.c Function for printing help. */


#include "para.h"
#include "ggo.h"
#include "version.h"

/**
 * Wrapper for printf() that exits on errors.
 *
 * \param fmt Usual format string.
 *
 * \return The return value of the underlying (successful) call to vprintf(3),
 * i.e. the number of characters printed, excluding the terminating null byte.
 */
__printf_1_2 int printf_or_die(const char *fmt, ...)
{
	va_list argp;
	int ret;

	va_start(argp, fmt);
	ret = vprintf(fmt, argp);
	va_end(argp);
	if (ret >= 0)
		return ret;
	exit(EXIT_FAILURE);
}

/**
 * Print one of the two given help texts.
 *
 * \param help contains the help texts.
 * \param flags What to print, see \ref ggo_print_help_flags.
 */
void ggo_print_help(struct ggo_help *help, unsigned flags)
{
	const char **p;

	if (help->purpose && (flags & GPH_PRINT_NAME_PURPOSE))
		printf_or_die("para_%s - %s\n", help->prefix, help->purpose);
	if (help->usage && (flags & GPH_PRINT_USAGE))
		printf_or_die("\n%s\n", help->usage);
	if (help->description && (flags & GPH_PRINT_DESCRIPTION))
		printf_or_die("\n%s\n", help->description);
	printf_or_die("\n");
	if (flags & GPH_DETAILED)
		p = help->detailed_help;
	else
		p = help->short_help;
	if (!p)
		return;
	for (; *p; p++)
		printf_or_die("%s\n", *p);
}
